/*
 * Created on 10.11.2003
 *
 * To change the template for this generated file go to
 * Window&gt;Preferences&gt;Java&gt;Code Generation&gt;Code and Comments
 */
package saxparser;

import java.util.EmptyStackException;
import java.util.Stack;

import javax.swing.JFrame;
import javax.swing.JScrollPane;
import javax.swing.JTree;
import javax.swing.tree.DefaultMutableTreeNode;
import javax.swing.tree.MutableTreeNode;
import javax.swing.tree.TreeNode;

import org.xml.sax.Attributes;
import org.xml.sax.ContentHandler;
import org.xml.sax.SAXException;
import org.xml.sax.XMLReader;
import org.xml.sax.helpers.DefaultHandler;
import org.xml.sax.helpers.XMLReaderFactory;

/**
 * @author jjoller
 * Einfache Baumausgabe eines XML Dokuments
 */
public class SAXCrimsonJTree extends DefaultHandler {

	private Stack nodes;

	/**
	 * startDocument() initialisiert pro XML Dokument einen Stack
	 * @throws SAXException
	 */
	public void startDocument() throws SAXException {
		nodes = new Stack();
	}

	/**
	 * Wurzelelement eines XML Dokuments
	 */
	private TreeNode root;

	/**
	 * Initialisierung pro neu eingelesenes Dokument
	 * @param namespaceURI
	 * @param localName
	 * @param qualifiedName
	 * @param atts
	 */
	public void startElement(
		String namespaceURI,
		String localName,
		String qualifiedName,
		Attributes atts) {

		String data;
		if (namespaceURI.equals(""))
			data = localName;
		else {
			data = '{' + namespaceURI + "} " + qualifiedName;
		}
		MutableTreeNode node = new DefaultMutableTreeNode(data);
		try {
			MutableTreeNode parent = (MutableTreeNode) nodes.peek();
			parent.insert(node, parent.getChildCount());
		} catch (EmptyStackException e) {
			root = node;
		}
		nodes.push(node);

	}
	/**
	 * Abschluss des XML Dokuments
	 * @param namespaceURI
	 * @param localName
	 * @param qualifiedName
	 */
	public void endElement(
		String namespaceURI,
		String localName,
		String qualifiedName) {
		nodes.pop();
	}

	/**
	 * Anzeige des Baumes pro Dokument
	 */
	public void endDocument() {

		JTree tree = new JTree(root);
		JScrollPane treeView = new JScrollPane(tree);
		JFrame f = new JFrame("XML Tree");

		f.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		f.getContentPane().add(treeView);
		f.pack();
		f.show();

	}

	public static void main(String[] args) {
		System.setProperty(
			"org.xml.sax.driver",
			"org.apache.crimson.parser.XMLReaderImpl");

		try {
			XMLReader parser =
				XMLReaderFactory.createXMLReader(
					"org.apache.crimson.parser.XMLReaderImpl");
			ContentHandler handler = new SAXCrimsonJTree();
			parser.setContentHandler(handler);
			String[] xml_docs = { "Test.xml", "XMLEingabe.xml" };
			for (int i = 0; i < xml_docs.length; i++) {
				parser.parse(xml_docs[i]);
			}

		} catch (Exception e) {
			System.err.println(e);
		}
	}
}
